import os

try:
    import configparser
except ImportError:
    import ConfigParser as configparser


def log_Runtime(log, mes, err):
    # Logging to the error output of
    log(2, mes, 0)
    if err:
        raise RuntimeError(mes)


def chek_con(file_name, log):
    # Check for a configuration file.
    file_name = os.curdir + "/" + file_name
    if not os.path.exists(file_name):
        log_Runtime(log, "File not found:" + file_name, True)
    return file_name


def read_conf(file_name, log):
    # Read the project configuration file.
    config = configparser.ConfigParser()
    config.read(file_name)
    if not config.has_option("Global", "Name"):
        log_Runtime(log, "There is no Name field in the config file", True)
    return config


def open_device_safe(device, conf, log):

    config = read_conf(chek_con(conf, log), log)  # Read config file

    # Load Lib version
    version = device.lib_version()  # Reading the library version
    if not config.has_section(version):  # Checking for a library partition
        log_Runtime(log, "Library version error " + version, True)

    try:
        device.open()
    except Exception:
        log_Runtime(log, "Not open device", True)

    Identy = device.get_identity_information()  # Get identy inform

    # s = ""  # Read controller_name # eyepoint-devices hasn't correct name!!!
    # for i in Identy._controller_name:  # _product_name:
    #     s = s + chr(i)
    #
    Name = config.get("Global", "Name")
    # if Name != s[:len(Name)-1].lower():
    #     device.close()
    #     log_Runtime(log, "The requested device does not " + Name, True)

    # Build version
    firmw = str(Identy._firmware_major) + "." + str(Identy._firmware_minor) + "." + str(Identy._firmware_bugfix)
    ind = 0
    firms = []

    # Information comparison
    for opt in config.options(version):
        firms.append(config.get(version, opt))
        if config.get(version, opt) == firmw:
            ind = 1

    if ind == 0:
        device.close()
        mes = "Version of the device " + firmw + "does not match the version of the library " + version
        log_Runtime(log, mes, False)

    log_Runtime(log, "Devise " + Name + " Lib " + version + " Firmware " + firmw, False)

    return ind, Name, version, firmw, firms
